#!/bin/sh

set -e

readonly version="3.30.1"

case "$( uname -s )" in
    Linux)
        shatool="sha256sum"
        sha256sum="ac31f077ef3378641fa25a3cb980d21b2f083982d3149a8f2eb9154f2b53696b"
        platform="linux-x86_64"
        ;;
    Darwin)
        shatool="shasum -a 256"
        sha256sum="51e12618829b811bba6f033ee8f39f6192da1b6abb20d82a7899d5134e879a4c"
        platform="macos-universal"
        ;;
    *)
        echo "Unrecognized platform $( uname -s )"
        exit 1
        ;;
esac
readonly shatool
readonly sha256sum
readonly platform

readonly filename="cmake-$version-$platform"
readonly tarball="$filename.tar.gz"

cd .gitlab

echo "$sha256sum  $tarball" > cmake.sha256sum
curl -OL "https://github.com/Kitware/CMake/releases/download/v$version/$tarball"
$shatool --check cmake.sha256sum
tar xf "$tarball"
mv "$filename" cmake

if [ "$( uname -s )" = "Darwin" ]; then
    ln -s CMake.app/Contents/bin cmake/bin
fi
